==> scanbot_sdk-2.2.2.tar.gz: lib/ehic_scanning_data.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/common_data.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'ehic_scanning_data.g.dart';

/// This class describes health insurance rtu-ui component scanned result
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class HealthInsuranceCardRecognitionResult extends Result {
  List<HealthInsuranceCardField> fields;
  HealthInsuranceCardDetectionStatus status;

  HealthInsuranceCardRecognitionResult(this.fields, this.status);

  factory HealthInsuranceCardRecognitionResult.fromJson(
          Map<String, dynamic> json) =>
      _$HealthInsuranceCardRecognitionResultFromJson(json);

  Map<String, dynamic> toJson() =>
      _$HealthInsuranceCardRecognitionResultToJson(this);

  HealthInsuranceCardRecognitionResult.canceled() {
    this.operationResult = OperationResult.CANCELED;
  }
}

/// Class that describes health insurance one scanned field
@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class HealthInsuranceCardField {
  final HealthInsuranceCardFieldType type;
  final String value;
  final double confidence;

  HealthInsuranceCardField(this.type, this.value, this.confidence);

  factory HealthInsuranceCardField.fromJson(Map<String, dynamic> json) =>
      _$HealthInsuranceCardFieldFromJson(json);

  Map<String, dynamic> toJson() => _$HealthInsuranceCardFieldToJson(this);
}

enum HealthInsuranceCardFieldType {
  SURNAME,
  GIVEN_NAME,
  DATE_OF_BIRTH,
  PERSONAL_IDENTIFICATION_NUMBER,
  INSTITUTION_NUMBER,
  INSTITUTION_NAME,
  CARD_NUMBER,
  CARD_EXPIRATION_DATE
}
enum HealthInsuranceCardDetectionStatus {
  SUCCESS,
  FAILED_DETECTION,
  FAILED_VALIDATION
}

/// Health insurance rtu-ui scanner configuration class
@JsonSerializable(nullable: true, includeIfNull: false, explicitToJson: true)
class HealthInsuranceScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color topBarButtonsColor;

  /// Background color outsidef the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color finderTextHintColor;
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsActiveColor;
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color bottomButtonsInactiveColor;

  bool cancelButtonHidden;

  /// Title of the cancel button.
  String cancelButtonTitle;

  String detectionStatusFailedDetectionText;

  String detectionStatusFailedValidationText;

  String detectionStatusSuccessText;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String finderTextHint;

  String flashButtonTitle;

  /// Thickness of the finder window's outline.
  int finderLineWidth;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode orientationLockMode;

  HealthInsuranceScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.bottomButtonsActiveColor,
      this.bottomButtonsInactiveColor,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.flashButtonTitle,
      this.finderLineWidth,
      this.flashEnabled,
      this.detectionStatusFailedDetectionText,
      this.detectionStatusFailedValidationText,
      this.detectionStatusSuccessText,
      this.orientationLockMode,
      this.cancelButtonHidden});

  factory HealthInsuranceScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$HealthInsuranceScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$HealthInsuranceScannerConfigurationToJson(this);
}

==> scanbot_sdk-2.4.1.tar.gz: lib/ehic_scanning_data.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/common_data.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'ehic_scanning_data.g.dart';

/// This class describes health insurance rtu-ui component scanned result
@JsonSerializable(
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class HealthInsuranceCardRecognitionResult extends Result {
  List<HealthInsuranceCardField> fields = <HealthInsuranceCardField>[];
  HealthInsuranceCardDetectionStatus? status;

  HealthInsuranceCardRecognitionResult(this.fields, this.status);

  factory HealthInsuranceCardRecognitionResult.fromJson(
          Map<String, dynamic> json) =>
      _$HealthInsuranceCardRecognitionResultFromJson(json);

  Map<String, dynamic> toJson() =>
      _$HealthInsuranceCardRecognitionResultToJson(this);

  HealthInsuranceCardRecognitionResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }
}

/// Class that describes health insurance one scanned field
@JsonSerializable( includeIfNull: false, explicitToJson: true)
class HealthInsuranceCardField {
  final HealthInsuranceCardFieldType type;
  final String value;
  final double confidence;

  HealthInsuranceCardField(this.type, this.value, this.confidence);

  factory HealthInsuranceCardField.fromJson(Map<String, dynamic> json) =>
      _$HealthInsuranceCardFieldFromJson(json);

  Map<String, dynamic> toJson() => _$HealthInsuranceCardFieldToJson(this);
}

enum HealthInsuranceCardFieldType {
  SURNAME,
  GIVEN_NAME,
  DATE_OF_BIRTH,
  PERSONAL_IDENTIFICATION_NUMBER,
  INSTITUTION_NUMBER,
  INSTITUTION_NAME,
  CARD_NUMBER,
  CARD_EXPIRATION_DATE
}
enum HealthInsuranceCardDetectionStatus {
  SUCCESS,
  FAILED_DETECTION,
  FAILED_VALIDATION
}

/// Health insurance rtu-ui scanner configuration class
@JsonSerializable( includeIfNull: false, explicitToJson: true)
class HealthInsuranceScannerConfiguration {
  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Background color outsidef the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// Color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// Color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomButtonsActiveColor;
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomButtonsInactiveColor;

  bool? cancelButtonHidden;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  String? detectionStatusFailedDetectionText;

  String? detectionStatusFailedValidationText;

  String? detectionStatusSuccessText;

  /// Title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// Text hint shown under the finder window.
  String? finderTextHint;

  String? flashButtonTitle;

  /// Thickness of the finder window's outline.
  int? finderLineWidth;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.

  CameraOrientationMode? orientationLockMode;

  HealthInsuranceScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.bottomButtonsActiveColor,
      this.bottomButtonsInactiveColor,
      this.cancelButtonTitle,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.flashButtonTitle,
      this.finderLineWidth,
      this.flashEnabled,
      this.detectionStatusFailedDetectionText,
      this.detectionStatusFailedValidationText,
      this.detectionStatusSuccessText,
      this.orientationLockMode,
      this.cancelButtonHidden});

  factory HealthInsuranceScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$HealthInsuranceScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$HealthInsuranceScannerConfigurationToJson(this);
}
